@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 15:00:05
-@LastEditTime: 2022-07-19 10:51:06
+@LastEditTime: 2022-08-16 13:55:36
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -243,9 +243,8 @@ class SubmitSkuHandler(ClientBaseHandler):
         user_prize_id = int(self.get_param("user_prize_id"))
         sku_name = self.get_param("sku_name")
         sku_id = self.get_param("sku_id")
-
-        frame_base_model = FrameBaseModel(context=self)
-        prize_roster_model = PrizeRosterModel(sub_table=frame_base_model.get_business_sub_table("prize_roster_tb", {"act_id": act_id, "user_id": 0}), context=self)
+        
+        prize_roster_model = PrizeRosterModel(context=self)
         prize_roster = prize_roster_model.get_entity_by_id(user_prize_id)
         if not prize_roster or prize_roster.open_id != open_id or prize_roster.app_id != app_id:
             return self.response_json_error("no_user_prize", "对不起，找不到该奖品")
