@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-15 11:30:45
-@LastEditTime: 2022-05-31 16:30:11
+@LastEditTime: 2022-11-21 17:15:55
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -25,16 +25,16 @@ class OSS2Helper:
         oss_config = config.get_value("oss_config")
         if not oss_config:
             oss_config = {}
-            oss_config["AK_ID"] = "LTAI4GAV8q6wxi2gqispR4my"
-            oss_config["AK_SECRET"] = "LWBuIALo4X4pnBDCwiuRjZur1Yhm5h"
-            oss_config["BUCKET_NAME"] = "mang-he"
-            oss_config["END_POINT"] = "oss-cn-zhangjiakou.aliyuncs.com"
-            oss_config["DOMAIN"] = "https://mang-he.oss-cn-zhangjiakou.aliyuncs.com/"
-        self.AK_ID = oss_config["AK_ID"]
-        self.AK_SECRET = oss_config["AK_SECRET"]
-        self.BUCKET_NAME = oss_config["BUCKET_NAME"]
-        self.END_POINT = oss_config["END_POINT"]
-        self.DOMAIN = oss_config["DOMAIN"]
+            oss_config["ak_id"] = "LTAI4GAV8q6wxi2gqispR4my"
+            oss_config["ak_secret"] = "LWBuIALo4X4pnBDCwiuRjZur1Yhm5h"
+            oss_config["bucket_name"] = "mang-he"
+            oss_config["end_point"] = "oss-cn-zhangjiakou.aliyuncs.com"
+            oss_config["demain"] = "https://mang-he.oss-cn-zhangjiakou.aliyuncs.com/"
+        self.ak_id = oss_config["ak_id"]
+        self.ak_secret = oss_config["ak_secret"]
+        self.bucket_name = oss_config["bucket_name"]
+        self.end_point = oss_config["end_point"]
+        self.demain = oss_config["demain"]
 
     @classmethod
     def upload(self, file_name, local_file='', folder='', is_auto_name=True, data=None):
@@ -56,8 +56,8 @@ class OSS2Helper:
             file_extension = os.path.splitext(file_name)[1]
             file_name = UUIDHelper.get_uuid().replace("-", "") + file_extension
 
-        auth = oss2.Auth(self.AK_ID, self.AK_SECRET)
-        bucket = oss2.Bucket(auth, self.END_POINT, self.BUCKET_NAME)
+        auth = oss2.Auth(self.ak_id, self.ak_secret)
+        bucket = oss2.Bucket(auth, self.end_point, self.bucket_name)
 
         folder = folder.strip('/')
         folder = folder + "/" if folder != "" else folder
@@ -76,7 +76,7 @@ class OSS2Helper:
 
         resource_path = ''
         if result.status == 200:
-            resource_path = self.DOMAIN + file_name
+            resource_path = self.demain + file_name
             # # HTTP返回码。
             # print('http status: {0}'.format(result.status))
             # # 请求ID。请求ID是请求的唯一标识，强烈建议在程序日志中添加此参数。
