@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-19 09:23:14
-@LastEditTime: 2022-11-24 09:33:31
+@LastEditTime: 2022-11-25 09:11:34
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -487,7 +487,7 @@ class WeChatHelper:
             except:
                 pass
             invoke_result_data.data = response.content
-            redis_init.set(redis_key, response.content, 3600)
+            redis_init.set(redis_key, response.content, 30*24*3600)
             return invoke_result_data
         except Exception as ex:
             self.logger_error.error("【create_qr_code】" + traceback.format_exc() + ":" + str(response.text))
