@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2022-11-15 11:12:09
+@LastEditTime: 2022-11-21 17:25:35
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -209,7 +209,7 @@ class UserBaseModel(FrameBaseModel):
                 if user_nick and user_account.user_nick != user_nick and is_update_user_nick == True:
                     user_account.user_nick = CryptographyHelper.emoji_to_emoji_base64(user_nick)
                     user_account.user_nick_encrypt = CryptographyHelper.base64_encrypt(user_nick)
-                if avatar and user_account.avatar != avatar:
+                if avatar and user_account.avatar != avatar and is_update_user_nick == True:
                     user_account.avatar = avatar
                 if union_id and user_account.union_id != union_id:
                     user_account.union_id = union_id
